@@ -272,6 +272,8 @@ class MIMEChecker():
 	# resort to libmagic
 	suffixes = {
 		'.js': 'application/javascript',
+		'.ts': 'application/javascript',
+		'.vue': 'application/javascript',
 		'.py': 'text/x-python',
 		'.html': 'text/html',
 		'.sh': 'text/x-shellscript',
@@ -365,8 +367,8 @@ def write_makefile(all_modules, special_cases, new_package_dir, target_language)
 
 	with open(os.path.join(new_package_dir, 'all_targets.mk'), 'w') as fd:
 		fd.write("# This file is auto-generated by univention-ucs-translation-build-package and should not be edited!\n\n")
-		fd.write('ALL_TARGETS := {}\n\n'.format(' \\\n\t'.join(mo_targets_list)))
-		fd.write('\n'.join(target_prerequisite))
+		fd.write('ALL_TARGETS := {}\n\n'.format(' \\\n\t'.join(sorted(mo_targets_list))))
+		fd.write('\n'.join(sorted(target_prerequisite)))
 		fd.write('\n')
 
 
